# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/broadcast/v1/room.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.rpc import status_pb2 as bilibili_dot_rpc_dot_status__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n bilibili/broadcast/v1/room.proto\x12\x15\x62ilibili.broadcast.v1\x1a\x19\x62ilibili/rpc/status.proto\x1a\x19google/protobuf/any.proto\"6\n\x0eRoomErrorEvent\x12$\n\x06status\x18\x01 \x01(\x0b\x32\x14.bilibili.rpc.Status\"\x0f\n\rRoomJoinEvent\"\x10\n\x0eRoomLeaveEvent\"K\n\x10RoomMessageEvent\x12\x13\n\x0btarget_path\x18\x01 \x01(\t\x12\"\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"5\n\x0fRoomOnlineEvent\x12\x0e\n\x06online\x18\x01 \x01(\x05\x12\x12\n\nall_online\x18\x02 \x01(\x05\"\xfe\x01\n\x07RoomReq\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x04join\x18\x02 \x01(\x0b\x32$.bilibili.broadcast.v1.RoomJoinEventH\x00\x12\x36\n\x05leave\x18\x03 \x01(\x0b\x32%.bilibili.broadcast.v1.RoomLeaveEventH\x00\x12\x38\n\x06online\x18\x04 \x01(\x0b\x32&.bilibili.broadcast.v1.RoomOnlineEventH\x00\x12\x36\n\x03msg\x18\x05 \x01(\x0b\x32\'.bilibili.broadcast.v1.RoomMessageEventH\x00\x42\x07\n\x05\x65vent\"\xb5\x02\n\x08RoomResp\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x04join\x18\x02 \x01(\x0b\x32$.bilibili.broadcast.v1.RoomJoinEventH\x00\x12\x36\n\x05leave\x18\x03 \x01(\x0b\x32%.bilibili.broadcast.v1.RoomLeaveEventH\x00\x12\x38\n\x06online\x18\x04 \x01(\x0b\x32&.bilibili.broadcast.v1.RoomOnlineEventH\x00\x12\x36\n\x03msg\x18\x05 \x01(\x0b\x32\'.bilibili.broadcast.v1.RoomMessageEventH\x00\x12\x34\n\x03\x65rr\x18\x06 \x01(\x0b\x32%.bilibili.broadcast.v1.RoomErrorEventH\x00\x42\x07\n\x05\x65vent2]\n\rBroadcastRoom\x12L\n\x05\x45nter\x12\x1e.bilibili.broadcast.v1.RoomReq\x1a\x1f.bilibili.broadcast.v1.RoomResp(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.v1.room_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROOMERROREVENT']._serialized_start=113
  _globals['_ROOMERROREVENT']._serialized_end=167
  _globals['_ROOMJOINEVENT']._serialized_start=169
  _globals['_ROOMJOINEVENT']._serialized_end=184
  _globals['_ROOMLEAVEEVENT']._serialized_start=186
  _globals['_ROOMLEAVEEVENT']._serialized_end=202
  _globals['_ROOMMESSAGEEVENT']._serialized_start=204
  _globals['_ROOMMESSAGEEVENT']._serialized_end=279
  _globals['_ROOMONLINEEVENT']._serialized_start=281
  _globals['_ROOMONLINEEVENT']._serialized_end=334
  _globals['_ROOMREQ']._serialized_start=337
  _globals['_ROOMREQ']._serialized_end=591
  _globals['_ROOMRESP']._serialized_start=594
  _globals['_ROOMRESP']._serialized_end=903
  _globals['_BROADCASTROOM']._serialized_start=905
  _globals['_BROADCASTROOM']._serialized_end=998
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/resource/privacy/v1/api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*bilibili/app/resource/privacy/v1/api.proto\x12 bilibili.app.resource.privacy.v1\"\x0e\n\x0cNoArgRequest\"\t\n\x07NoReply\"\xe3\x01\n\x11PrivacyConfigItem\x12P\n\x13privacy_config_type\x18\x01 \x01(\x0e\x32\x33.bilibili.app.resource.privacy.v1.PrivacyConfigType\x12\r\n\x05title\x18\x02 \x01(\t\x12\x43\n\x05state\x18\x03 \x01(\x0e\x32\x34.bilibili.app.resource.privacy.v1.PrivacyConfigState\x12\x11\n\tsub_title\x18\x04 \x01(\t\x12\x15\n\rsub_title_uri\x18\x05 \x01(\t\"f\n\x12PrivacyConfigReply\x12P\n\x13privacy_config_item\x18\x01 \x01(\x0b\x32\x33.bilibili.app.resource.privacy.v1.PrivacyConfigItem\"\xb0\x01\n\x17SetPrivacyConfigRequest\x12P\n\x13privacy_config_type\x18\x01 \x01(\x0e\x32\x33.bilibili.app.resource.privacy.v1.PrivacyConfigType\x12\x43\n\x05state\x18\x02 \x01(\x0e\x32\x34.bilibili.app.resource.privacy.v1.PrivacyConfigState*)\n\x12PrivacyConfigState\x12\t\n\x05\x63lose\x10\x00\x12\x08\n\x04open\x10\x01*/\n\x11PrivacyConfigType\x12\x08\n\x04none\x10\x00\x12\x10\n\x0c\x64ynamic_city\x10\x01\x32\xfa\x01\n\x07Privacy\x12u\n\rPrivacyConfig\x12..bilibili.app.resource.privacy.v1.NoArgRequest\x1a\x34.bilibili.app.resource.privacy.v1.PrivacyConfigReply\x12x\n\x10SetPrivacyConfig\x12\x39.bilibili.app.resource.privacy.v1.SetPrivacyConfigRequest\x1a).bilibili.app.resource.privacy.v1.NoReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.resource.privacy.v1.api_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PRIVACYCONFIGSTATE']._serialized_start=620
  _globals['_PRIVACYCONFIGSTATE']._serialized_end=661
  _globals['_PRIVACYCONFIGTYPE']._serialized_start=663
  _globals['_PRIVACYCONFIGTYPE']._serialized_end=710
  _globals['_NOARGREQUEST']._serialized_start=80
  _globals['_NOARGREQUEST']._serialized_end=94
  _globals['_NOREPLY']._serialized_start=96
  _globals['_NOREPLY']._serialized_end=105
  _globals['_PRIVACYCONFIGITEM']._serialized_start=108
  _globals['_PRIVACYCONFIGITEM']._serialized_end=335
  _globals['_PRIVACYCONFIGREPLY']._serialized_start=337
  _globals['_PRIVACYCONFIGREPLY']._serialized_end=439
  _globals['_SETPRIVACYCONFIGREQUEST']._serialized_start=442
  _globals['_SETPRIVACYCONFIGREQUEST']._serialized_end=618
  _globals['_PRIVACY']._serialized_start=713
  _globals['_PRIVACY']._serialized_end=963
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AddContractReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_MESSAGE_FIELD_NUMBER: builtins.int
    ALLOW_REPLY_FIELD_NUMBER: builtins.int
    INPUT_TEXT_FIELD_NUMBER: builtins.int
    INPUT_TITLE_FIELD_NUMBER: builtins.int
    allow_message: builtins.bool
    """"""
    allow_reply: builtins.bool
    """"""
    input_text: builtins.str
    """"""
    input_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        allow_message: builtins.bool = ...,
        allow_reply: builtins.bool = ...,
        input_text: builtins.str = ...,
        input_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_message", b"allow_message", "allow_reply", b"allow_reply", "input_text", b"input_text", "input_title", b"input_title"]) -> None: ...

global___AddContractReply = AddContractReply

@typing_extensions.final
class AddContractReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMON_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    @property
    def common(self) -> global___CommonReq:
        """"""
    mid: builtins.int
    """"""
    up_mid: builtins.int
    """"""
    aid: builtins.int
    """"""
    source: builtins.int
    """"""
    def __init__(
        self,
        *,
        common: global___CommonReq | None = ...,
        mid: builtins.int = ...,
        up_mid: builtins.int = ...,
        aid: builtins.int = ...,
        source: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["common", b"common"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "common", b"common", "mid", b"mid", "source", b"source", "up_mid", b"up_mid"]) -> None: ...

global___AddContractReq = AddContractReq

@typing_extensions.final
class CommonReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLATFORM_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    platform: builtins.str
    """"""
    build: builtins.int
    """"""
    buvid: builtins.str
    """"""
    mobi_app: builtins.str
    """"""
    device: builtins.str
    """"""
    ip: builtins.str
    """"""
    spmid: builtins.str
    """"""
    def __init__(
        self,
        *,
        platform: builtins.str = ...,
        build: builtins.int = ...,
        buvid: builtins.str = ...,
        mobi_app: builtins.str = ...,
        device: builtins.str = ...,
        ip: builtins.str = ...,
        spmid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build", b"build", "buvid", b"buvid", "device", b"device", "ip", b"ip", "mobi_app", b"mobi_app", "platform", b"platform", "spmid", b"spmid"]) -> None: ...

global___CommonReq = CommonReq

@typing_extensions.final
class ContractCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    sub_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        sub_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sub_title", b"sub_title", "title", b"title"]) -> None: ...

global___ContractCard = ContractCard

@typing_extensions.final
class ContractConfigReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_FOLLOW_DISPLAY_FIELD_NUMBER: builtins.int
    IS_TRIPLE_DISPLAY_FIELD_NUMBER: builtins.int
    CONTRACT_CARD_FIELD_NUMBER: builtins.int
    is_follow_display: builtins.int
    """"""
    is_triple_display: builtins.int
    """"""
    @property
    def contract_card(self) -> global___ContractCard:
        """"""
    def __init__(
        self,
        *,
        is_follow_display: builtins.int = ...,
        is_triple_display: builtins.int = ...,
        contract_card: global___ContractCard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["contract_card", b"contract_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["contract_card", b"contract_card", "is_follow_display", b"is_follow_display", "is_triple_display", b"is_triple_display"]) -> None: ...

global___ContractConfigReply = ContractConfigReply

@typing_extensions.final
class ContractConfigReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMON_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    @property
    def common(self) -> global___CommonReq:
        """"""
    mid: builtins.int
    """"""
    up_mid: builtins.int
    """"""
    aid: builtins.int
    """"""
    source: builtins.int
    """"""
    def __init__(
        self,
        *,
        common: global___CommonReq | None = ...,
        mid: builtins.int = ...,
        up_mid: builtins.int = ...,
        aid: builtins.int = ...,
        source: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["common", b"common"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "common", b"common", "mid", b"mid", "source", b"source", "up_mid", b"up_mid"]) -> None: ...

global___ContractConfigReq = ContractConfigReq



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/web/space/v1/space.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/web/space/v1/space.proto\x12\x15\x62ilibili.web.space.v1\"\t\n\x07NoReply\"\xb8\x01\n\rOfficialReply\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uid\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12\x0e\n\x06scheme\x18\x05 \x01(\t\x12\x0c\n\x04rcmd\x18\x06 \x01(\t\x12\x0f\n\x07ios_url\x18\x07 \x01(\t\x12\x13\n\x0b\x61ndroid_url\x18\x08 \x01(\t\x12\x0e\n\x06\x62utton\x18\t \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\n \x01(\t\x12\r\n\x05mtime\x18\x0b \x01(\x03\"\x1e\n\x0fOfficialRequest\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"[\n\tPhotoMall\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03img\x18\x03 \x01(\t\x12\x11\n\tnight_img\x18\x04 \x01(\t\x12\x14\n\x0cis_activated\x18\x05 \x01(\x03\"D\n\x12PhotoMallListReply\x12.\n\x04list\x18\x01 \x03(\x0b\x32 .bilibili.web.space.v1.PhotoMall\"@\n\x10PhotoMallListReq\x12\x0f\n\x07mobiapp\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0e\n\x06\x64\x65vice\x18\x03 \x01(\t\"\x81\x01\n\x0cPrivacyReply\x12\x41\n\x07privacy\x18\x01 \x03(\x0b\x32\x30.bilibili.web.space.v1.PrivacyReply.PrivacyEntry\x1a.\n\x0cPrivacyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\x1d\n\x0ePrivacyRequest\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"I\n\x0eSetTopPhotoReq\x12\x0f\n\x07mobiapp\x18\x01 \x01(\t\x12\x0b\n\x03i_d\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\x05\"\xe5\x02\n\x11SpaceSettingReply\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x03\x12\x11\n\tfav_video\x18\x02 \x01(\x03\x12\x13\n\x0b\x63oins_video\x18\x03 \x01(\x03\x12\x13\n\x0blikes_video\x18\x04 \x01(\x03\x12\x0f\n\x07\x62\x61ngumi\x18\x05 \x01(\x03\x12\x13\n\x0bplayed_game\x18\x06 \x01(\x03\x12\x0e\n\x06groups\x18\x07 \x01(\x03\x12\r\n\x05\x63omic\x18\x08 \x01(\x03\x12\x0c\n\x04\x62_bq\x18\t \x01(\x03\x12\x10\n\x08\x64ress_up\x18\n \x01(\x03\x12\x19\n\x11\x64isable_following\x18\x0b \x01(\x03\x12\x15\n\rlive_playback\x18\x0c \x01(\x03\x12\x19\n\x11\x63lose_space_medal\x18\r \x01(\x03\x12\x19\n\x11only_show_wearing\x18\x0e \x01(\x03\x12\x1b\n\x13\x64isable_show_school\x18\x0f \x01(\x03\x12\x18\n\x10\x64isable_show_nft\x18\x10 \x01(\x03\"\x1e\n\x0fSpaceSettingReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"?\n\x08TopPhoto\x12\x0f\n\x07img_url\x18\x01 \x01(\t\x12\x15\n\rnight_img_url\x18\x02 \x01(\t\x12\x0b\n\x03sid\x18\x03 \x01(\x03\"5\n\x0bTopPhotoArc\x12\x0c\n\x04show\x18\x01 \x01(\x08\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03pic\x18\x03 \x01(\t\"#\n\x14TopPhotoArcCancelReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"~\n\rTopPhotoReply\x12\x32\n\ttop_photo\x18\x01 \x01(\x0b\x32\x1f.bilibili.web.space.v1.TopPhoto\x12\x39\n\rtop_photo_arc\x18\x02 \x01(\x0b\x32\".bilibili.web.space.v1.TopPhotoArc\"]\n\x0bTopPhotoReq\x12\x0f\n\x07mobiapp\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\r\n\x05\x62uild\x18\x03 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x04 \x01(\t\x12\x11\n\tlogin_mid\x18\x05 \x01(\x03\"R\n\x10UpActivityTabReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05state\x18\x02 \x01(\x05\x12\x10\n\x08tab_cont\x18\x03 \x01(\x03\x12\x10\n\x08tab_name\x18\x04 \x01(\t\"$\n\x11UpActivityTabResp\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x16\n\x14UpRcmdBlackListReply\"\x89\x01\n\x0cUserTabReply\x12\x10\n\x08tab_type\x18\x01 \x01(\x05\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x10\n\x08tab_name\x18\x03 \x01(\t\x12\x11\n\ttab_order\x18\x04 \x01(\x05\x12\x10\n\x08tab_cont\x18\x05 \x01(\x03\x12\x12\n\nis_default\x18\x06 \x01(\x05\x12\x0f\n\x07h5_link\x18\x07 \x01(\t\"6\n\nUserTabReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04plat\x18\x02 \x01(\x05\x12\r\n\x05\x62uild\x18\x03 \x01(\x05\"#\n\x11WhitelistAddReply\x12\x0e\n\x06\x61\x64\x64_ok\x18\x01 \x01(\x08\"<\n\x0fWhitelistAddReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05stime\x18\x02 \x01(\x03\x12\r\n\x05\x65time\x18\x03 \x01(\x03\"\"\n\x0eWhitelistReply\x12\x10\n\x08is_white\x18\x01 \x01(\x08\"\x1b\n\x0cWhitelistReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\"!\n\x10WhitelistUpReply\x12\r\n\x05up_ok\x18\x01 \x01(\x08\"I\n\x17WhitelistValidTimeReply\x12\x10\n\x08is_white\x18\x01 \x01(\x08\x12\r\n\x05stime\x18\x02 \x01(\x03\x12\r\n\x05\x65time\x18\x03 \x01(\x03*1\n\x0cTopPhotoType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03PIC\x10\x01\x12\x0b\n\x07\x41RCHIVE\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.web.space.v1.space_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRIVACYREPLY_PRIVACYENTRY._options = None
  _PRIVACYREPLY_PRIVACYENTRY._serialized_options = b'8\001'
  _globals['_TOPPHOTOTYPE']._serialized_start=2145
  _globals['_TOPPHOTOTYPE']._serialized_end=2194
  _globals['_NOREPLY']._serialized_start=60
  _globals['_NOREPLY']._serialized_end=69
  _globals['_OFFICIALREPLY']._serialized_start=72
  _globals['_OFFICIALREPLY']._serialized_end=256
  _globals['_OFFICIALREQUEST']._serialized_start=258
  _globals['_OFFICIALREQUEST']._serialized_end=288
  _globals['_PHOTOMALL']._serialized_start=290
  _globals['_PHOTOMALL']._serialized_end=381
  _globals['_PHOTOMALLLISTREPLY']._serialized_start=383
  _globals['_PHOTOMALLLISTREPLY']._serialized_end=451
  _globals['_PHOTOMALLLISTREQ']._serialized_start=453
  _globals['_PHOTOMALLLISTREQ']._serialized_end=517
  _globals['_PRIVACYREPLY']._serialized_start=520
  _globals['_PRIVACYREPLY']._serialized_end=649
  _globals['_PRIVACYREPLY_PRIVACYENTRY']._serialized_start=603
  _globals['_PRIVACYREPLY_PRIVACYENTRY']._serialized_end=649
  _globals['_PRIVACYREQUEST']._serialized_start=651
  _globals['_PRIVACYREQUEST']._serialized_end=680
  _globals['_SETTOPPHOTOREQ']._serialized_start=682
  _globals['_SETTOPPHOTOREQ']._serialized_end=755
  _globals['_SPACESETTINGREPLY']._serialized_start=758
  _globals['_SPACESETTINGREPLY']._serialized_end=1115
  _globals['_SPACESETTINGREQ']._serialized_start=1117
  _globals['_SPACESETTINGREQ']._serialized_end=1147
  _globals['_TOPPHOTO']._serialized_start=1149
  _globals['_TOPPHOTO']._serialized_end=1212
  _globals['_TOPPHOTOARC']._serialized_start=1214
  _globals['_TOPPHOTOARC']._serialized_end=1267
  _globals['_TOPPHOTOARCCANCELREQ']._serialized_start=1269
  _globals['_TOPPHOTOARCCANCELREQ']._serialized_end=1304
  _globals['_TOPPHOTOREPLY']._serialized_start=1306
  _globals['_TOPPHOTOREPLY']._serialized_end=1432
  _globals['_TOPPHOTOREQ']._serialized_start=1434
  _globals['_TOPPHOTOREQ']._serialized_end=1527
  _globals['_UPACTIVITYTABREQ']._serialized_start=1529
  _globals['_UPACTIVITYTABREQ']._serialized_end=1611
  _globals['_UPACTIVITYTABRESP']._serialized_start=1613
  _globals['_UPACTIVITYTABRESP']._serialized_end=1649
  _globals['_UPRCMDBLACKLISTREPLY']._serialized_start=1651
  _globals['_UPRCMDBLACKLISTREPLY']._serialized_end=1673
  _globals['_USERTABREPLY']._serialized_start=1676
  _globals['_USERTABREPLY']._serialized_end=1813
  _globals['_USERTABREQ']._serialized_start=1815
  _globals['_USERTABREQ']._serialized_end=1869
  _globals['_WHITELISTADDREPLY']._serialized_start=1871
  _globals['_WHITELISTADDREPLY']._serialized_end=1906
  _globals['_WHITELISTADDREQ']._serialized_start=1908
  _globals['_WHITELISTADDREQ']._serialized_end=1968
  _globals['_WHITELISTREPLY']._serialized_start=1970
  _globals['_WHITELISTREPLY']._serialized_end=2004
  _globals['_WHITELISTREQ']._serialized_start=2006
  _globals['_WHITELISTREQ']._serialized_end=2033
  _globals['_WHITELISTUPREPLY']._serialized_start=2035
  _globals['_WHITELISTUPREPLY']._serialized_end=2068
  _globals['_WHITELISTVALIDTIMEREPLY']._serialized_start=2070
  _globals['_WHITELISTVALIDTIMEREPLY']._serialized_end=2143
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ErrorRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    error: builtins.int
    """"""
    time: builtins.int
    """"""
    delay: builtins.int
    """"""
    def __init__(
        self,
        *,
        error: builtins.int = ...,
        time: builtins.int = ...,
        delay: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delay", b"delay", "error", b"error", "time", b"time"]) -> None: ...

global___ErrorRequest = ErrorRequest

@typing_extensions.final
class ErrorResponse(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    host: builtins.str
    """"""
    time: builtins.int
    """"""
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "time", b"time"]) -> None: ...

global___ErrorResponse = ErrorResponse

@typing_extensions.final
class PingRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_FIELD_NUMBER: builtins.int
    time: builtins.int
    """"""
    def __init__(
        self,
        *,
        time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["time", b"time"]) -> None: ...

global___PingRequest = PingRequest

@typing_extensions.final
class PingResponse(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    host: builtins.str
    """"""
    time: builtins.int
    """"""
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "time", b"time"]) -> None: ...

global___PingResponse = PingResponse

@typing_extensions.final
class SayRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    """"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content"]) -> None: ...

global___SayRequest = SayRequest

@typing_extensions.final
class SayResponse(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    host: builtins.str
    """"""
    content: builtins.str
    """"""
    time: builtins.int
    """"""
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        content: builtins.str = ...,
        time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "host", b"host", "time", b"time"]) -> None: ...

global___SayResponse = SayResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2
import bilireq.grpc.protos.bilibili.dagw.component.avatar.v1.plugin_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AvatarItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_SIZE_FIELD_NUMBER: builtins.int
    LAYERS_FIELD_NUMBER: builtins.int
    FALLBACK_LAYERS_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    @property
    def container_size(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.SizeSpec:
        """"""
    @property
    def layers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LayerGroup]:
        """"""
    @property
    def fallback_layers(self) -> global___LayerGroup:
        """"""
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        container_size: bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.SizeSpec | None = ...,
        layers: collections.abc.Iterable[global___LayerGroup] | None = ...,
        fallback_layers: global___LayerGroup | None = ...,
        mid: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_size", b"container_size", "fallback_layers", b"fallback_layers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_size", b"container_size", "fallback_layers", b"fallback_layers", "layers", b"layers", "mid", b"mid"]) -> None: ...

global___AvatarItem = AvatarItem

@typing_extensions.final
class BasicLayerResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RES_TYPE_FIELD_NUMBER: builtins.int
    RES_IMAGE_FIELD_NUMBER: builtins.int
    RES_ANIMATION_FIELD_NUMBER: builtins.int
    RES_NATIVE_DRAW_FIELD_NUMBER: builtins.int
    res_type: builtins.int
    """"""
    @property
    def res_image(self) -> global___ResImage:
        """"""
    @property
    def res_animation(self) -> global___ResAnimation:
        """"""
    @property
    def res_native_draw(self) -> global___ResNativeDraw:
        """/"""
    def __init__(
        self,
        *,
        res_type: builtins.int = ...,
        res_image: global___ResImage | None = ...,
        res_animation: global___ResAnimation | None = ...,
        res_native_draw: global___ResNativeDraw | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["payload", b"payload", "res_animation", b"res_animation", "res_image", b"res_image", "res_native_draw", b"res_native_draw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["payload", b"payload", "res_animation", b"res_animation", "res_image", b"res_image", "res_native_draw", b"res_native_draw", "res_type", b"res_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["payload", b"payload"]) -> typing_extensions.Literal["res_image", "res_animation", "res_native_draw"] | None: ...

global___BasicLayerResource = BasicLayerResource

@typing_extensions.final
class GeneralConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class WebCssStyleEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    WEB_CSS_STYLE_FIELD_NUMBER: builtins.int
    @property
    def web_css_style(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        web_css_style: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["web_css_style", b"web_css_style"]) -> None: ...

global___GeneralConfig = GeneralConfig

@typing_extensions.final
class Layer(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAYER_ID_FIELD_NUMBER: builtins.int
    VISIBLE_FIELD_NUMBER: builtins.int
    GENERAL_SPEC_FIELD_NUMBER: builtins.int
    LAYER_CONFIG_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    layer_id: builtins.str
    """"""
    visible: builtins.bool
    """"""
    @property
    def general_spec(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.LayerGeneralSpec:
        """"""
    @property
    def layer_config(self) -> global___LayerConfig:
        """"""
    @property
    def resource(self) -> global___BasicLayerResource:
        """"""
    def __init__(
        self,
        *,
        layer_id: builtins.str = ...,
        visible: builtins.bool = ...,
        general_spec: bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.LayerGeneralSpec | None = ...,
        layer_config: global___LayerConfig | None = ...,
        resource: global___BasicLayerResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["general_spec", b"general_spec", "layer_config", b"layer_config", "resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["general_spec", b"general_spec", "layer_config", b"layer_config", "layer_id", b"layer_id", "resource", b"resource", "visible", b"visible"]) -> None: ...

global___Layer = Layer

@typing_extensions.final
class LayerConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___LayerTagConfig: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___LayerTagConfig | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TAGS_FIELD_NUMBER: builtins.int
    IS_CRITICAL_FIELD_NUMBER: builtins.int
    ALLOW_OVER_PAINT_FIELD_NUMBER: builtins.int
    LAYER_MASK_FIELD_NUMBER: builtins.int
    @property
    def tags(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___LayerTagConfig]:
        """"""
    is_critical: builtins.bool
    """"""
    allow_over_paint: builtins.bool
    """"""
    @property
    def layer_mask(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.MaskProperty:
        """"""
    def __init__(
        self,
        *,
        tags: collections.abc.Mapping[builtins.str, global___LayerTagConfig] | None = ...,
        is_critical: builtins.bool = ...,
        allow_over_paint: builtins.bool = ...,
        layer_mask: bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.MaskProperty | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["layer_mask", b"layer_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_over_paint", b"allow_over_paint", "is_critical", b"is_critical", "layer_mask", b"layer_mask", "tags", b"tags"]) -> None: ...

global___LayerConfig = LayerConfig

@typing_extensions.final
class LayerGroup(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    LAYERS_FIELD_NUMBER: builtins.int
    GROUP_MASK_FIELD_NUMBER: builtins.int
    IS_CRITICAL_GROUP_FIELD_NUMBER: builtins.int
    group_id: builtins.str
    """"""
    @property
    def layers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Layer]:
        """"""
    @property
    def group_mask(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.MaskProperty:
        """"""
    is_critical_group: builtins.bool
    """"""
    def __init__(
        self,
        *,
        group_id: builtins.str = ...,
        layers: collections.abc.Iterable[global___Layer] | None = ...,
        group_mask: bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.MaskProperty | None = ...,
        is_critical_group: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["group_mask", b"group_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_id", b"group_id", "group_mask", b"group_mask", "is_critical_group", b"is_critical_group", "layers", b"layers"]) -> None: ...

global___LayerGroup = LayerGroup

@typing_extensions.final
class LayerTagConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_TYPE_FIELD_NUMBER: builtins.int
    GENERAL_CONFIG_FIELD_NUMBER: builtins.int
    GYRO_CONFIG_FIELD_NUMBER: builtins.int
    COMMENT_DOUBLECLICK_CONFIG_FIELD_NUMBER: builtins.int
    LIVE_ANIME_CONFIG_FIELD_NUMBER: builtins.int
    config_type: builtins.int
    """"""
    @property
    def general_config(self) -> global___GeneralConfig:
        """"""
    @property
    def gyro_config(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.v1.plugin_pb2.GyroConfig:
        """"""
    @property
    def comment_doubleClick_config(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.v1.plugin_pb2.CommentDoubleClickConfig:
        """"""
    @property
    def live_anime_config(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.v1.plugin_pb2.LiveAnimeConfig:
        """"""
    def __init__(
        self,
        *,
        config_type: builtins.int = ...,
        general_config: global___GeneralConfig | None = ...,
        gyro_config: bilireq.grpc.protos.bilibili.dagw.component.avatar.v1.plugin_pb2.GyroConfig | None = ...,
        comment_doubleClick_config: bilireq.grpc.protos.bilibili.dagw.component.avatar.v1.plugin_pb2.CommentDoubleClickConfig | None = ...,
        live_anime_config: bilireq.grpc.protos.bilibili.dagw.component.avatar.v1.plugin_pb2.LiveAnimeConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["comment_doubleClick_config", b"comment_doubleClick_config", "config", b"config", "general_config", b"general_config", "gyro_config", b"gyro_config", "live_anime_config", b"live_anime_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment_doubleClick_config", b"comment_doubleClick_config", "config", b"config", "config_type", b"config_type", "general_config", b"general_config", "gyro_config", b"gyro_config", "live_anime_config", b"live_anime_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config", b"config"]) -> typing_extensions.Literal["general_config", "gyro_config", "comment_doubleClick_config", "live_anime_config"] | None: ...

global___LayerTagConfig = LayerTagConfig

@typing_extensions.final
class ResAnimation(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WEBP_SRC_FIELD_NUMBER: builtins.int
    @property
    def webp_src(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.ResourceSource:
        """"""
    def __init__(
        self,
        *,
        webp_src: bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.ResourceSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["webp_src", b"webp_src"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["webp_src", b"webp_src"]) -> None: ...

global___ResAnimation = ResAnimation

@typing_extensions.final
class ResImage(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_SRC_FIELD_NUMBER: builtins.int
    @property
    def image_src(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.ResourceSource:
        """"""
    def __init__(
        self,
        *,
        image_src: bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.ResourceSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["image_src", b"image_src"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_src", b"image_src"]) -> None: ...

global___ResImage = ResImage

@typing_extensions.final
class ResNativeDraw(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRAW_SRC_FIELD_NUMBER: builtins.int
    @property
    def draw_src(self) -> bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.ResourceSource:
        """"""
    def __init__(
        self,
        *,
        draw_src: bilireq.grpc.protos.bilibili.dagw.component.avatar.common.common_pb2.ResourceSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["draw_src", b"draw_src"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["draw_src", b"draw_src"]) -> None: ...

global___ResNativeDraw = ResNativeDraw



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DynamicAutoPlay(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    @property
    def value(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    def __init__(
        self,
        *,
        value: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___DynamicAutoPlay = DynamicAutoPlay

@typing_extensions.final
class DynamicDeviceConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_PLAY_FIELD_NUMBER: builtins.int
    @property
    def auto_play(self) -> global___DynamicAutoPlay:
        """"""
    def __init__(
        self,
        *,
        auto_play: global___DynamicAutoPlay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_play", b"auto_play"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_play", b"auto_play"]) -> None: ...

global___DynamicDeviceConfig = DynamicDeviceConfig



import base64
from typing import Dict

import rsa

from ..utils import post

BASE_URL = "https://passport.bilibili.com/"


async def _encrypt_pwd(pwd: str) -> str:
    """加密密码"""
    url = f"{BASE_URL}api/oauth2/getKey"
    resp: Dict[str, str] = await post(url, reqtype="app")
    pub_key = rsa.PublicKey.load_pkcs1_openssl_pem(resp["key"].encode())
    msg = (resp["hash"] + pwd).encode()
    return base64.b64encode(rsa.encrypt(msg, pub_key)).decode("ascii")


async def pwd_login(username: str, password: str, **kwargs):
    """
    账号密码登录

    Args:
        username (str): 用户名
        password (str): 密码

    Raises:
        ResponseCodeError: 返回码不为 0
            -629: 用户名或密码错误
            86048: 密码错误超过次数限制,请尝试扫码登录或短信登录（十分钟重置）



    Returns:
        Dict: 登录 Token
    """
    url = f"{BASE_URL}x/passport-tv-login/login"
    params = {"username": username, "password": await _encrypt_pwd(password)}
    return await post(url, params=params, reqtype="app", **kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/interfaces/v1/history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/app/interfaces/v1/history.proto\x12\x19\x62ilibili.app.interface.v1\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"\x98\x01\n\x0b\x43\x61rdArticle\x12\x0e\n\x06\x63overs\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x18\n\x10\x64isplayAttention\x18\x04 \x01(\x08\x12\r\n\x05\x62\x61\x64ge\x18\x05 \x01(\t\x12\x35\n\x08relation\x18\x06 \x01(\x0b\x32#.bilibili.app.interface.v1.Relation\"`\n\nCardCheese\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x10\n\x08subtitle\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\x03\"\xa3\x01\n\x08\x43\x61rdLive\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0b\n\x03tag\x18\x04 \x01(\t\x12\x0e\n\x06ststus\x18\x05 \x01(\x05\x12\x19\n\x11\x64isplay_attention\x18\x06 \x01(\x08\x12\x35\n\x08relation\x18\x07 \x01(\x0b\x32#.bilibili.app.interface.v1.Relation\"l\n\x07\x43\x61rdOGV\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x10\n\x08subtitle\x18\x04 \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\x03\"\xbd\x02\n\x07\x43\x61rdUGC\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0b\n\x03mid\x18\x05 \x01(\x03\x12\x19\n\x11\x64isplay_attention\x18\x06 \x01(\x08\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x0c\n\x04page\x18\x08 \x01(\x05\x12\x10\n\x08subtitle\x18\t \x01(\t\x12\x35\n\x08relation\x18\n \x01(\x0b\x32#.bilibili.app.interface.v1.Relation\x12\x0c\n\x04\x62vid\x18\x0b \x01(\t\x12\x0e\n\x06videos\x18\x0c \x01(\x03\x12\x12\n\nshort_link\x18\r \x01(\t\x12\x16\n\x0eshare_subtitle\x18\x0e \x01(\t\x12\x0c\n\x04view\x18\x0f \x01(\x03\x12\r\n\x05state\x18\x10 \x01(\x03\"\x1c\n\x08\x43learReq\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\"$\n\x06\x43ursor\x12\x0b\n\x03max\x18\x01 \x01(\x03\x12\r\n\x05maxTp\x18\x02 \x01(\x05\"\xeb\x03\n\nCursorItem\x12\x36\n\x08\x63\x61rd_ugc\x18\x01 \x01(\x0b\x32\".bilibili.app.interface.v1.CardUGCH\x00\x12\x36\n\x08\x63\x61rd_ogv\x18\x02 \x01(\x0b\x32\".bilibili.app.interface.v1.CardOGVH\x00\x12>\n\x0c\x63\x61rd_article\x18\x03 \x01(\x0b\x32&.bilibili.app.interface.v1.CardArticleH\x00\x12\x38\n\tcard_live\x18\x04 \x01(\x0b\x32#.bilibili.app.interface.v1.CardLiveH\x00\x12<\n\x0b\x63\x61rd_cheese\x18\x05 \x01(\x0b\x32%.bilibili.app.interface.v1.CardCheeseH\x00\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x0e\n\x06viewAt\x18\x08 \x01(\x03\x12\x0b\n\x03kid\x18\t \x01(\x03\x12\x0b\n\x03oid\x18\n \x01(\x03\x12\x10\n\x08\x62usiness\x18\x0b \x01(\t\x12\n\n\x02tp\x18\x0c \x01(\x05\x12\x31\n\x02\x64t\x18\r \x01(\x0b\x32%.bilibili.app.interface.v1.DeviceType\x12\x11\n\thas_share\x18\x0e \x01(\x08\x42\x0b\n\tcard_item\"\xba\x01\n\x0b\x43ursorReply\x12\x34\n\x05items\x18\x01 \x03(\x0b\x32%.bilibili.app.interface.v1.CursorItem\x12\x31\n\x03tab\x18\x02 \x03(\x0b\x32$.bilibili.app.interface.v1.CursorTab\x12\x31\n\x06\x63ursor\x18\x03 \x01(\x0b\x32!.bilibili.app.interface.v1.Cursor\x12\x0f\n\x07hasMore\x18\x04 \x01(\x08\"\xdd\x01\n\tCursorReq\x12\x31\n\x06\x63ursor\x18\x01 \x01(\x0b\x32!.bilibili.app.interface.v1.Cursor\x12\x10\n\x08\x62usiness\x18\x02 \x01(\t\x12\x46\n\x0eplayer_preload\x18\x03 \x01(\x0b\x32..bilibili.app.interface.v1.PlayerPreloadParams\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"J\n\tCursorTab\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06router\x18\x03 \x01(\t\x12\r\n\x05\x66ocus\x18\x04 \x01(\x08\"\x9d\x01\n\rCursorV2Reply\x12\x34\n\x05items\x18\x01 \x03(\x0b\x32%.bilibili.app.interface.v1.CursorItem\x12\x31\n\x06\x63ursor\x18\x02 \x01(\x0b\x32!.bilibili.app.interface.v1.Cursor\x12\x0f\n\x07hasMore\x18\x03 \x01(\x08\x12\x12\n\nempty_link\x18\x04 \x01(\t\"\xf1\x01\n\x0b\x43ursorV2Req\x12\x31\n\x06\x63ursor\x18\x01 \x01(\x0b\x32!.bilibili.app.interface.v1.Cursor\x12\x10\n\x08\x62usiness\x18\x02 \x01(\t\x12\x46\n\x0eplayer_preload\x18\x03 \x01(\x0b\x32..bilibili.app.interface.v1.PlayerPreloadParams\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08is_local\x18\x05 \x01(\x08\"A\n\tDeleteReq\x12\x34\n\x08his_info\x18\x01 \x01(\x0b\x32\".bilibili.app.interface.v1.HisInfo\"G\n\nDeviceType\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.bilibili.app.interface.v1.DT\x12\x0c\n\x04icon\x18\x02 \x01(\t\"(\n\x07HisInfo\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x0b\n\x03kid\x18\x02 \x01(\x03\"D\n\x0fHistoryTabReply\x12\x31\n\x03tab\x18\x01 \x03(\x0b\x32$.bilibili.app.interface.v1.CursorTab\"l\n\rHistoryTabReq\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x38\n\x06source\x18\x02 \x01(\x0e\x32(.bilibili.app.interface.v1.HistorySource\x12\x0f\n\x07keyword\x18\x03 \x01(\t\"v\n\x12LatestHistoryReply\x12\x34\n\x05items\x18\x01 \x01(\x0b\x32%.bilibili.app.interface.v1.CursorItem\x12\r\n\x05scene\x18\x02 \x01(\t\x12\r\n\x05rtime\x18\x03 \x01(\x03\x12\x0c\n\x04\x66lag\x18\x04 \x01(\t\"l\n\x10LatestHistoryReq\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x46\n\x0eplayer_preload\x18\x02 \x01(\x0b\x32..bilibili.app.interface.v1.PlayerPreloadParams\"\t\n\x07NoReply\"!\n\x04Page\x12\n\n\x02pn\x18\x01 \x01(\x03\x12\r\n\x05total\x18\x02 \x01(\x03\"a\n\x13PlayerPreloadParams\x12\n\n\x02qn\x18\x01 \x01(\x03\x12\r\n\x05\x66nver\x18\x02 \x01(\x03\x12\r\n\x05\x66nval\x18\x03 \x01(\x03\x12\x11\n\tforceHost\x18\x04 \x01(\x03\x12\r\n\x05\x66ourk\x18\x05 \x01(\x03\"B\n\x08Relation\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\"\x83\x01\n\x0bSearchReply\x12\x34\n\x05items\x18\x01 \x03(\x0b\x32%.bilibili.app.interface.v1.CursorItem\x12\x0f\n\x07hasMore\x18\x02 \x01(\x08\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.bilibili.app.interface.v1.Page\":\n\tSearchReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\n\n\x02pn\x18\x02 \x01(\x03\x12\x10\n\x08\x62usiness\x18\x03 \x01(\t*S\n\x02\x44T\x12\x0b\n\x07Unknown\x10\x00\x12\t\n\x05Phone\x10\x01\x12\x07\n\x03Pad\x10\x02\x12\x06\n\x02PC\x10\x03\x12\x06\n\x02TV\x10\x04\x12\x07\n\x03\x43\x61r\x10\x05\x12\x07\n\x03Iot\x10\x06\x12\n\n\x06\x41ndPad\x10\x07*6\n\rHistorySource\x12\x11\n\rhistory_VALUE\x10\x00\x12\x12\n\x0eshopping_VALUE\x10\x01\x32\x8e\x05\n\x07History\x12\x62\n\nHistoryTab\x12(.bilibili.app.interface.v1.HistoryTabReq\x1a*.bilibili.app.interface.v1.HistoryTabReply\x12V\n\x06\x43ursor\x12$.bilibili.app.interface.v1.CursorReq\x1a&.bilibili.app.interface.v1.CursorReply\x12\\\n\x08\x43ursorV2\x12&.bilibili.app.interface.v1.CursorV2Req\x1a(.bilibili.app.interface.v1.CursorV2Reply\x12R\n\x06\x44\x65lete\x12$.bilibili.app.interface.v1.DeleteReq\x1a\".bilibili.app.interface.v1.NoReply\x12V\n\x06Search\x12$.bilibili.app.interface.v1.SearchReq\x1a&.bilibili.app.interface.v1.SearchReply\x12P\n\x05\x43lear\x12#.bilibili.app.interface.v1.ClearReq\x1a\".bilibili.app.interface.v1.NoReply\x12k\n\rLatestHistory\x12+.bilibili.app.interface.v1.LatestHistoryReq\x1a-.bilibili.app.interface.v1.LatestHistoryReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.interfaces.v1.history_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DT']._serialized_start=3424
  _globals['_DT']._serialized_end=3507
  _globals['_HISTORYSOURCE']._serialized_start=3509
  _globals['_HISTORYSOURCE']._serialized_end=3563
  _globals['_CARDARTICLE']._serialized_start=122
  _globals['_CARDARTICLE']._serialized_end=274
  _globals['_CARDCHEESE']._serialized_start=276
  _globals['_CARDCHEESE']._serialized_end=372
  _globals['_CARDLIVE']._serialized_start=375
  _globals['_CARDLIVE']._serialized_end=538
  _globals['_CARDOGV']._serialized_start=540
  _globals['_CARDOGV']._serialized_end=648
  _globals['_CARDUGC']._serialized_start=651
  _globals['_CARDUGC']._serialized_end=968
  _globals['_CLEARREQ']._serialized_start=970
  _globals['_CLEARREQ']._serialized_end=998
  _globals['_CURSOR']._serialized_start=1000
  _globals['_CURSOR']._serialized_end=1036
  _globals['_CURSORITEM']._serialized_start=1039
  _globals['_CURSORITEM']._serialized_end=1530
  _globals['_CURSORREPLY']._serialized_start=1533
  _globals['_CURSORREPLY']._serialized_end=1719
  _globals['_CURSORREQ']._serialized_start=1722
  _globals['_CURSORREQ']._serialized_end=1943
  _globals['_CURSORTAB']._serialized_start=1945
  _globals['_CURSORTAB']._serialized_end=2019
  _globals['_CURSORV2REPLY']._serialized_start=2022
  _globals['_CURSORV2REPLY']._serialized_end=2179
  _globals['_CURSORV2REQ']._serialized_start=2182
  _globals['_CURSORV2REQ']._serialized_end=2423
  _globals['_DELETEREQ']._serialized_start=2425
  _globals['_DELETEREQ']._serialized_end=2490
  _globals['_DEVICETYPE']._serialized_start=2492
  _globals['_DEVICETYPE']._serialized_end=2563
  _globals['_HISINFO']._serialized_start=2565
  _globals['_HISINFO']._serialized_end=2605
  _globals['_HISTORYTABREPLY']._serialized_start=2607
  _globals['_HISTORYTABREPLY']._serialized_end=2675
  _globals['_HISTORYTABREQ']._serialized_start=2677
  _globals['_HISTORYTABREQ']._serialized_end=2785
  _globals['_LATESTHISTORYREPLY']._serialized_start=2787
  _globals['_LATESTHISTORYREPLY']._serialized_end=2905
  _globals['_LATESTHISTORYREQ']._serialized_start=2907
  _globals['_LATESTHISTORYREQ']._serialized_end=3015
  _globals['_NOREPLY']._serialized_start=3017
  _globals['_NOREPLY']._serialized_end=3026
  _globals['_PAGE']._serialized_start=3028
  _globals['_PAGE']._serialized_end=3061
  _globals['_PLAYERPRELOADPARAMS']._serialized_start=3063
  _globals['_PLAYERPRELOADPARAMS']._serialized_end=3160
  _globals['_RELATION']._serialized_start=3162
  _globals['_RELATION']._serialized_end=3228
  _globals['_SEARCHREPLY']._serialized_start=3231
  _globals['_SEARCHREPLY']._serialized_end=3362
  _globals['_SEARCHREQ']._serialized_start=3364
  _globals['_SEARCHREQ']._serialized_end=3422
  _globals['_HISTORY']._serialized_start=3566
  _globals['_HISTORY']._serialized_end=4220
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/api/probe/v1/probe.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/api/probe/v1/probe.proto\x12\x15\x62ilibili.api.probe.v1\"E\n\tCodeReply\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03id1\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\x03\x12\x11\n\tmessage_s\x18\x04 \x01(\t\"\x17\n\x07\x43odeReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\"\x19\n\x0b\x43reateTopic\x12\n\n\x02id\x18\x01 \x01(\x03\"\x19\n\tCreatTask\x12\x0c\n\x04task\x18\x01 \x01(\t\"J\n\x14\x44ynamicMessageUpdate\x12\x32\n\x04\x62ody\x18\x01 \x01(\x0b\x32$.bilibili.api.probe.v1.SimpleMessage\"\xc8\x04\n\x08\x45mbedded\x12\x10\n\x08\x62ool_val\x18\x01 \x01(\x08\x12\x11\n\tint32_val\x18\x02 \x01(\x05\x12\x11\n\tint64_val\x18\x03 \x01(\x03\x12\x11\n\tfloat_val\x18\x04 \x01(\x02\x12\x12\n\ndouble_val\x18\x05 \x01(\x01\x12\x12\n\nstring_val\x18\x06 \x01(\t\x12\x19\n\x11repeated_bool_val\x18\x07 \x03(\x08\x12\x1a\n\x12repeated_int32_val\x18\x08 \x03(\x05\x12\x1a\n\x12repeated_int64_val\x18\t \x03(\x03\x12\x1a\n\x12repeated_float_val\x18\n \x03(\x02\x12\x1b\n\x13repeated_double_val\x18\x0b \x03(\x01\x12\x1b\n\x13repeated_string_val\x18\x0c \x03(\t\x12I\n\x0emap_string_val\x18\r \x03(\x0b\x32\x31.bilibili.api.probe.v1.Embedded.MapStringValEntry\x12G\n\rmap_error_val\x18\x0e \x03(\x0b\x32\x30.bilibili.api.probe.v1.Embedded.MapErrorValEntry\x1a\x33\n\x11MapStringValEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aW\n\x10MapErrorValEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.bilibili.api.probe.v1.ErrorMessage:\x02\x38\x01\"=\n\x0c\x45rrorMessage\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"0\n\nProbeReply\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\"&\n\x08ProbeReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05\x62uvid\x18\x02 \x01(\t\"H\n\x10ProbeStreamReply\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\"/\n\x0eProbeStreamReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x10\n\x08sequence\x18\x02 \x01(\x03\"#\n\rProbeSubReply\x12\x12\n\nmessage_id\x18\x01 \x01(\x03\"\x1c\n\x0bProbeSubReq\x12\r\n\x05\x62uvid\x18\x01 \x01(\t\"w\n\rSimpleMessage\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x0c\n\x04lang\x18\x03 \x01(\t\x12\x0c\n\x04\x63\x61te\x18\x04 \x01(\x05\x12\x31\n\x08\x65mbedded\x18\x05 \x01(\x0b\x32\x1f.bilibili.api.probe.v1.Embedded\"3\n\x04Task\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x02 \x01(\t\x12\r\n\x05\x63\x61\x63he\x18\x03 \x01(\x08*o\n\x08\x43\x61tegory\x12\x18\n\x14\x43\x41TEGORY_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x43\x41TEGORY_ONE\x10\x01\x12\x10\n\x0c\x43\x41TEGORY_TWO\x10\x02\x12\x12\n\x0e\x43\x41TEGORY_THREE\x10\x03\x12\x11\n\rCATEGORY_FOUR\x10\x04*A\n\x0b\x45rrorReason\x12\x15\n\x11PROBE_UNSPECIFIED\x10\x00\x12\x1b\n\x17PROBE_CATEGORY_NOTFOUND\x10\x01\x32\xd7\x02\n\x05Probe\x12L\n\x08TestCode\x12\x1e.bilibili.api.probe.v1.CodeReq\x1a .bilibili.api.probe.v1.CodeReply\x12M\n\x07TestReq\x12\x1f.bilibili.api.probe.v1.ProbeReq\x1a!.bilibili.api.probe.v1.ProbeReply\x12\\\n\nTestStream\x12%.bilibili.api.probe.v1.ProbeStreamReq\x1a\'.bilibili.api.probe.v1.ProbeStreamReply\x12S\n\x07TestSub\x12\".bilibili.api.probe.v1.ProbeSubReq\x1a$.bilibili.api.probe.v1.ProbeSubReply2\xd2\x03\n\x0cProbeService\x12R\n\x04\x45\x63ho\x12$.bilibili.api.probe.v1.SimpleMessage\x1a$.bilibili.api.probe.v1.SimpleMessage\x12V\n\x08\x45\x63hoBody\x12$.bilibili.api.probe.v1.SimpleMessage\x1a$.bilibili.api.probe.v1.SimpleMessage\x12X\n\nEchoDelete\x12$.bilibili.api.probe.v1.SimpleMessage\x1a$.bilibili.api.probe.v1.SimpleMessage\x12U\n\tEchoError\x12#.bilibili.api.probe.v1.ErrorMessage\x1a#.bilibili.api.probe.v1.ErrorMessage\x12\x65\n\tEchoPatch\x12+.bilibili.api.probe.v1.DynamicMessageUpdate\x1a+.bilibili.api.probe.v1.DynamicMessageUpdateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.api.probe.v1.probe_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EMBEDDED_MAPSTRINGVALENTRY._options = None
  _EMBEDDED_MAPSTRINGVALENTRY._serialized_options = b'8\001'
  _EMBEDDED_MAPERRORVALENTRY._options = None
  _EMBEDDED_MAPERRORVALENTRY._serialized_options = b'8\001'
  _globals['_CATEGORY']._serialized_start=1390
  _globals['_CATEGORY']._serialized_end=1501
  _globals['_ERRORREASON']._serialized_start=1503
  _globals['_ERRORREASON']._serialized_end=1568
  _globals['_CODEREPLY']._serialized_start=60
  _globals['_CODEREPLY']._serialized_end=129
  _globals['_CODEREQ']._serialized_start=131
  _globals['_CODEREQ']._serialized_end=154
  _globals['_CREATETOPIC']._serialized_start=156
  _globals['_CREATETOPIC']._serialized_end=181
  _globals['_CREATTASK']._serialized_start=183
  _globals['_CREATTASK']._serialized_end=208
  _globals['_DYNAMICMESSAGEUPDATE']._serialized_start=210
  _globals['_DYNAMICMESSAGEUPDATE']._serialized_end=284
  _globals['_EMBEDDED']._serialized_start=287
  _globals['_EMBEDDED']._serialized_end=871
  _globals['_EMBEDDED_MAPSTRINGVALENTRY']._serialized_start=731
  _globals['_EMBEDDED_MAPSTRINGVALENTRY']._serialized_end=782
  _globals['_EMBEDDED_MAPERRORVALENTRY']._serialized_start=784
  _globals['_EMBEDDED_MAPERRORVALENTRY']._serialized_end=871
  _globals['_ERRORMESSAGE']._serialized_start=873
  _globals['_ERRORMESSAGE']._serialized_end=934
  _globals['_PROBEREPLY']._serialized_start=936
  _globals['_PROBEREPLY']._serialized_end=984
  _globals['_PROBEREQ']._serialized_start=986
  _globals['_PROBEREQ']._serialized_end=1024
  _globals['_PROBESTREAMREPLY']._serialized_start=1026
  _globals['_PROBESTREAMREPLY']._serialized_end=1098
  _globals['_PROBESTREAMREQ']._serialized_start=1100
  _globals['_PROBESTREAMREQ']._serialized_end=1147
  _globals['_PROBESUBREPLY']._serialized_start=1149
  _globals['_PROBESUBREPLY']._serialized_end=1184
  _globals['_PROBESUBREQ']._serialized_start=1186
  _globals['_PROBESUBREQ']._serialized_end=1214
  _globals['_SIMPLEMESSAGE']._serialized_start=1216
  _globals['_SIMPLEMESSAGE']._serialized_end=1335
  _globals['_TASK']._serialized_start=1337
  _globals['_TASK']._serialized_end=1388
  _globals['_PROBE']._serialized_start=1571
  _globals['_PROBE']._serialized_end=1914
  _globals['_PROBESERVICE']._serialized_start=1917
  _globals['_PROBESERVICE']._serialized_end=2383
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class BanUser(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """用户mid"""
    limit: builtins.int
    """封禁业务"""
    time: builtins.int
    """封禁时间"""
    mode: builtins.int
    """模式
    1:add 2:remove
    """
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        limit: builtins.int = ...,
        time: builtins.int = ...,
        mode: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["limit", b"limit", "mode", b"mode", "time", b"time", "uid", b"uid"]) -> None: ...

global___BanUser = BanUser

@typing_extensions.final
class ReqOpBlacklist(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BAN_USERS_FIELD_NUMBER: builtins.int
    @property
    def ban_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BanUser]:
        """需要封禁/解封的用户信息"""
    def __init__(
        self,
        *,
        ban_users: collections.abc.Iterable[global___BanUser] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ban_users", b"ban_users"]) -> None: ...

global___ReqOpBlacklist = ReqOpBlacklist

@typing_extensions.final
class RspOpBlacklist(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILED_USERS_FIELD_NUMBER: builtins.int
    @property
    def failed_users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """"""
    def __init__(
        self,
        *,
        failed_users: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failed_users", b"failed_users"]) -> None: ...

global___RspOpBlacklist = RspOpBlacklist



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/dynamic/v2/campus.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from bilireq.grpc.protos.bilibili.pagination import pagination_pb2 as bilibili_dot_pagination_dot_pagination__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.common import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_common_dot_dynamic__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$bilibili/app/dynamic/v2/campus.proto\x12\x17\x62ilibili.app.dynamic.v2\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a$bilibili/pagination/pagination.proto\x1a)bilibili/app/dynamic/common/dynamic.proto\x1a%bilibili/app/dynamic/v2/dynamic.proto\"\xac\x01\n\x13\x43\x61mpusWaterFlowItem\x12\x11\n\titem_type\x18\x01 \x01(\x05\x12:\n\x08wh_ratio\x18\x02 \x01(\x0b\x32(.bilibili.app.dynamic.common.ItemWHRatio\x12>\n\x0citem_default\x18\x03 \x01(\x0b\x32&.bilibili.app.dynamic.v2.WFItemDefaultH\x00\x42\x06\n\x04item\"\xb2\x01\n\x10WaterFlowRcmdReq\x12\x11\n\tcampus_id\x18\x01 \x01(\x03\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x03 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x38\n\x04\x66rom\x18\x04 \x01(\x0e\x32*.bilibili.app.dynamic.v2.CampusRcmdReqFrom\"\x8a\x01\n\x11WaterFlowRcmdResp\x12;\n\x05items\x18\x01 \x03(\x0b\x32,.bilibili.app.dynamic.v2.CampusWaterFlowItem\x12\x38\n\x06offset\x18\x02 \x01(\x0b\x32(.bilibili.pagination.FeedPaginationReply\"\xc0\x03\n\rWFItemDefault\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x41\n\rbottom_left_1\x18\x03 \x01(\x0b\x32*.bilibili.app.dynamic.v2.CoverIconWithText\x12\x41\n\rbottom_left_2\x18\x04 \x01(\x0b\x32*.bilibili.app.dynamic.v2.CoverIconWithText\x12\x42\n\x0e\x62ottom_right_1\x18\x05 \x01(\x0b\x32*.bilibili.app.dynamic.v2.CoverIconWithText\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x38\n\x0brcmd_reason\x18\x07 \x01(\x0b\x32#.bilibili.app.dynamic.v2.RcmdReason\x12L\n\x0b\x61nnotations\x18\x08 \x03(\x0b\x32\x37.bilibili.app.dynamic.v2.WFItemDefault.AnnotationsEntry\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32p\n\x06\x43\x61mpus\x12\x66\n\rWaterFlowRcmd\x12).bilibili.app.dynamic.v2.WaterFlowRcmdReq\x1a*.bilibili.app.dynamic.v2.WaterFlowRcmdRespb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.dynamic.v2.campus_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WFITEMDEFAULT_ANNOTATIONSENTRY._options = None
  _WFITEMDEFAULT_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _globals['_CAMPUSWATERFLOWITEM']._serialized_start=236
  _globals['_CAMPUSWATERFLOWITEM']._serialized_end=408
  _globals['_WATERFLOWRCMDREQ']._serialized_start=411
  _globals['_WATERFLOWRCMDREQ']._serialized_end=589
  _globals['_WATERFLOWRCMDRESP']._serialized_start=592
  _globals['_WATERFLOWRCMDRESP']._serialized_end=730
  _globals['_WFITEMDEFAULT']._serialized_start=733
  _globals['_WFITEMDEFAULT']._serialized_end=1181
  _globals['_WFITEMDEFAULT_ANNOTATIONSENTRY']._serialized_start=1131
  _globals['_WFITEMDEFAULT_ANNOTATIONSENTRY']._serialized_end=1181
  _globals['_CAMPUS']._serialized_start=1183
  _globals['_CAMPUS']._serialized_end=1295
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.viewunite.v1 import viewunite_pb2 as bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2


class ViewStub(object):
    """统一视频信息接口(7.23启用)
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.View = channel.unary_unary(
                '/bilibili.app.viewunite.v1.View/View',
                request_serializer=bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2.ViewReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2.ViewReply.FromString,
                )
        self.ViewProgress = channel.unary_unary(
                '/bilibili.app.viewunite.v1.View/ViewProgress',
                request_serializer=bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2.ViewProgressReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2.ViewProgressReply.FromString,
                )


class ViewServicer(object):
    """统一视频信息接口(7.23启用)
    """

    def View(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ViewProgress(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ViewServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'View': grpc.unary_unary_rpc_method_handler(
                    servicer.View,
                    request_deserializer=bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2.ViewReq.FromString,
                    response_serializer=bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2.ViewReply.SerializeToString,
            ),
            'ViewProgress': grpc.unary_unary_rpc_method_handler(
                    servicer.ViewProgress,
                    request_deserializer=bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2.ViewProgressReq.FromString,
                    response_serializer=bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2.ViewProgressReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.viewunite.v1.View', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class View(object):
    """统一视频信息接口(7.23启用)
    """

    @staticmethod
    def View(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.viewunite.v1.View/View',
            bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2.ViewReq.SerializeToString,
            bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2.ViewReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ViewProgress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.viewunite.v1.View/ViewProgress',
            bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2.ViewProgressReq.SerializeToString,
            bilibili_dot_app_dot_viewunite_dot_v1_dot_viewunite__pb2.ViewProgressReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/archive/v1/archive.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/app/archive/v1/archive.proto\x12\x17\x62ilibili.app.archive.v1\"\xad\x06\n\x03\x41rc\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0e\n\x06videos\x18\x02 \x01(\x03\x12\x0f\n\x07type_id\x18\x03 \x01(\x05\x12\x11\n\ttype_name\x18\x04 \x01(\t\x12\x11\n\tcopyright\x18\x05 \x01(\x05\x12\x0b\n\x03pic\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x0f\n\x07pubdate\x18\x08 \x01(\x03\x12\r\n\x05\x63time\x18\t \x01(\x03\x12\x0c\n\x04\x64\x65sc\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\x05\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\x0c \x01(\x05\x12\x11\n\tattribute\x18\r \x01(\x05\x12\x0b\n\x03tag\x18\x0e \x01(\t\x12\x0c\n\x04tags\x18\x0f \x03(\t\x12\x10\n\x08\x64uration\x18\x10 \x01(\x03\x12\x12\n\nmission_id\x18\x11 \x01(\x03\x12\x10\n\x08order_id\x18\x12 \x01(\x03\x12\x14\n\x0credirect_url\x18\x13 \x01(\t\x12\x0f\n\x07\x66orward\x18\x14 \x01(\x03\x12/\n\x06rights\x18\x15 \x01(\x0b\x32\x1f.bilibili.app.archive.v1.Rights\x12/\n\x06\x61uthor\x18\x16 \x01(\x0b\x32\x1f.bilibili.app.archive.v1.Author\x12+\n\x04stat\x18\x17 \x01(\x0b\x32\x1d.bilibili.app.archive.v1.Stat\x12\x15\n\rreport_result\x18\x18 \x01(\t\x12\x0f\n\x07\x64ynamic\x18\x19 \x01(\t\x12\x11\n\tfirst_cid\x18\x1a \x01(\x03\x12\x35\n\tdimension\x18\x1b \x01(\x0b\x32\".bilibili.app.archive.v1.Dimension\x12\x36\n\nstaff_info\x18\x1c \x03(\x0b\x32\".bilibili.app.archive.v1.StaffInfo\x12\x11\n\tseason_id\x18\x1d \x01(\x03\x12\x14\n\x0c\x61ttribute_v2\x18\x1e \x01(\x03\x12:\n\x0cseason_theme\x18\x1f \x01(\x0b\x32$.bilibili.app.archive.v1.SeasonTheme\x12\x15\n\rshort_link_v2\x18( \x01(\t\x12\x12\n\nup_from_v2\x18) \x01(\x05\x12\x13\n\x0b\x66irst_frame\x18* \x01(\t\"1\n\x06\x41uthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\":\n\tDimension\x12\r\n\x05width\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"\xc7\x01\n\x04Page\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\x0c\n\x04part\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\x0b\n\x03vid\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x07 \x01(\t\x12\x0f\n\x07webLink\x18\x08 \x01(\t\x12\x35\n\tdimension\x18\t \x01(\x0b\x32\".bilibili.app.archive.v1.Dimension\x12\x13\n\x0b\x66irst_frame\x18\n \x01(\t\"\x85\x02\n\x06Rights\x12\n\n\x02\x62p\x18\x01 \x01(\x05\x12\x0c\n\x04\x65lec\x18\x02 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x03 \x01(\x05\x12\r\n\x05movie\x18\x04 \x01(\x05\x12\x0b\n\x03pay\x18\x05 \x01(\x05\x12\x0b\n\x03hd5\x18\x06 \x01(\x05\x12\x12\n\nno_reprint\x18\x07 \x01(\x05\x12\x10\n\x08\x61utoplay\x18\x08 \x01(\x05\x12\x0f\n\x07ugc_pay\x18\t \x01(\x05\x12\x16\n\x0eis_cooperation\x18\n \x01(\x05\x12\x17\n\x0fugc_pay_preview\x18\x0b \x01(\x05\x12\x15\n\rno_background\x18\x0c \x01(\x05\x12\x0f\n\x07\x61rc_pay\x18\r \x01(\x05\x12\x16\n\x0epay_free_watch\x18\x0e \x01(\x05\"N\n\x0bSeasonTheme\x12\x10\n\x08\x62g_color\x18\x01 \x01(\t\x12\x19\n\x11selected_bg_color\x18\x02 \x01(\t\x12\x12\n\ntext_color\x18\x03 \x01(\t\":\n\tStaffInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\tattribute\x18\x03 \x01(\x03\"\xae\x01\n\x04Stat\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04view\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61nmaku\x18\x03 \x01(\x05\x12\r\n\x05reply\x18\x04 \x01(\x05\x12\x0b\n\x03\x66\x61v\x18\x05 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x06 \x01(\x05\x12\r\n\x05share\x18\x07 \x01(\x05\x12\x10\n\x08now_rank\x18\x08 \x01(\x05\x12\x10\n\x08his_rank\x18\t \x01(\x05\x12\x0c\n\x04like\x18\n \x01(\x05\x12\x0f\n\x07\x64islike\x18\x0b \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.archive.v1.archive_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ARC']._serialized_start=67
  _globals['_ARC']._serialized_end=880
  _globals['_AUTHOR']._serialized_start=882
  _globals['_AUTHOR']._serialized_end=931
  _globals['_DIMENSION']._serialized_start=933
  _globals['_DIMENSION']._serialized_end=991
  _globals['_PAGE']._serialized_start=994
  _globals['_PAGE']._serialized_end=1193
  _globals['_RIGHTS']._serialized_start=1196
  _globals['_RIGHTS']._serialized_end=1457
  _globals['_SEASONTHEME']._serialized_start=1459
  _globals['_SEASONTHEME']._serialized_end=1537
  _globals['_STAFFINFO']._serialized_start=1539
  _globals['_STAFFINFO']._serialized_end=1597
  _globals['_STAT']._serialized_start=1600
  _globals['_STAT']._serialized_end=1774
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilibili.im.interfaces.inner_interface.v1 import api_pb2 as bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2


class InnerInterfaceStub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpdateListInn = channel.unary_unary(
                '/bilibili.im.interface.inner.interface.v1.InnerInterface/UpdateListInn',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2.ReqOpBlacklist.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2.RspOpBlacklist.FromString,
                )


class InnerInterfaceServicer(object):
    """
    """

    def UpdateListInn(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InnerInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpdateListInn': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateListInn,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2.ReqOpBlacklist.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2.RspOpBlacklist.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.im.interface.inner.interface.v1.InnerInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InnerInterface(object):
    """
    """

    @staticmethod
    def UpdateListInn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interface.inner.interface.v1.InnerInterface/UpdateListInn',
            bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2.ReqOpBlacklist.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_inner__interface_dot_v1_dot_api__pb2.RspOpBlacklist.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/interfaces/v1/media.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&bilibili/app/interfaces/v1/media.proto\x12\x19\x62ilibili.app.interface.v1\"\xc3\x02\n\x07\x42igItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x18\n\x10\x63over_right_text\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text1\x18\x05 \x01(\t\x12\x18\n\x10\x63over_left_icon1\x18\x06 \x01(\x03\x12\x18\n\x10\x63over_left_text2\x18\x07 \x01(\t\x12\x18\n\x10\x63over_left_icon2\x18\x08 \x01(\x03\x12\x36\n\tuser_card\x18\t \x01(\x0b\x32#.bilibili.app.interface.v1.UserCard\x12:\n\x0blike_button\x18\n \x01(\x0b\x32%.bilibili.app.interface.v1.LikeButton\x12\r\n\x05param\x18\x0b \x01(\x03\"\x9e\x01\n\x06\x42utton\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\x03\x12\x34\n\x08\x62ut_type\x18\x05 \x01(\x0e\x32\".bilibili.app.interface.v1.ButType\x12\x14\n\x0c\x66ollow_state\x18\x06 \x01(\x05\x12\x11\n\thas_title\x18\x07 \x01(\t\"M\n\x04\x43\x61st\x12\x36\n\x06person\x18\x01 \x03(\x0b\x32&.bilibili.app.interface.v1.MediaPerson\x12\r\n\x05title\x18\x02 \x01(\t\"5\n\x0b\x43hannelInfo\x12\x12\n\nchannel_id\x18\x01 \x01(\x03\x12\x12\n\nsubscribed\x18\x02 \x01(\x08\"\x9b\x03\n\nLikeButton\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x12\n\nshow_count\x18\x03 \x01(\x08\x12\r\n\x05\x65vent\x18\x04 \x01(\t\x12\x10\n\x08selected\x18\x05 \x01(\x05\x12\x10\n\x08\x65vent_v2\x18\x06 \x01(\t\x12\x44\n\rlike_resource\x18\x07 \x01(\x0b\x32-.bilibili.app.interface.v1.LikeButtonResource\x12H\n\x11\x64is_like_resource\x18\x08 \x01(\x0b\x32-.bilibili.app.interface.v1.LikeButtonResource\x12J\n\x13like_night_resource\x18\t \x01(\x0b\x32-.bilibili.app.interface.v1.LikeButtonResource\x12N\n\x17\x64is_like_night_resource\x18\n \x01(\x0b\x32-.bilibili.app.interface.v1.LikeButtonResource\"/\n\x12LikeButtonResource\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t\"+\n\x08LikeCard\x12\x0c\n\x04like\x18\x01 \x01(\x03\x12\x11\n\tis_follow\x18\x02 \x01(\x08\"\x81\x01\n\tMediaCard\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x11\n\tcur_title\x18\x02 \x01(\t\x12\r\n\x05style\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\x12\x34\n\tbut_first\x18\x05 \x01(\x0b\x32!.bilibili.app.interface.v1.Button\"\xa9\x01\n\x10MediaDetailReply\x12-\n\x04\x63\x61st\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.interface.v1.Cast\x12/\n\x05staff\x18\x02 \x01(\x0b\x32 .bilibili.app.interface.v1.Staff\x12\x35\n\x08overview\x18\x03 \x01(\x0b\x32#.bilibili.app.interface.v1.Overview\"2\n\x0eMediaDetailReq\x12\x0e\n\x06\x62iz_id\x18\x01 \x01(\x03\x12\x10\n\x08\x62iz_type\x18\x02 \x01(\x03\"\x12\n\x10MediaFollowReply\"*\n\x0eMediaFollowReq\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x05\"h\n\x0bMediaPerson\x12\x11\n\treal_name\x18\x01 \x01(\t\x12\x12\n\nsquare_url\x18\x02 \x01(\t\x12\x11\n\tcharacter\x18\x03 \x01(\t\x12\x11\n\tperson_id\x18\x04 \x01(\x03\x12\x0c\n\x04type\x18\x05 \x01(\t\"j\n\x12MediaRelationReply\x12\x0e\n\x06offset\x18\x01 \x01(\t\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x32\n\x04list\x18\x03 \x03(\x0b\x32$.bilibili.app.interface.v1.SmallItem\"a\n\x10MediaRelationReq\x12\x0e\n\x06\x62iz_id\x18\x01 \x01(\x03\x12\x10\n\x08\x62iz_type\x18\x02 \x01(\x03\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\x03\x12\x0e\n\x06offset\x18\x05 \x01(\t\x12\n\n\x02ps\x18\x06 \x01(\x05\"\xd3\x01\n\rMediaTabReply\x12\x38\n\nmedia_card\x18\x01 \x01(\x0b\x32$.bilibili.app.interface.v1.MediaCard\x12/\n\x03tab\x18\x02 \x03(\x0b\x32\".bilibili.app.interface.v1.ShowTab\x12\x19\n\x11\x64\x65\x66\x61ult_tab_index\x18\x03 \x01(\x03\x12<\n\x0c\x63hannel_info\x18\x04 \x01(\x0b\x32&.bilibili.app.interface.v1.ChannelInfo\"\xbb\x01\n\x0bMediaTabReq\x12\x0e\n\x06\x62iz_id\x18\x01 \x01(\x03\x12\x10\n\x08\x62iz_type\x18\x02 \x01(\x03\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\r\n\x05spmid\x18\x04 \x01(\t\x12>\n\x04\x61rgs\x18\x05 \x03(\x0b\x32\x30.bilibili.app.interface.v1.MediaTabReq.ArgsEntry\x1a+\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x0fMediaVideoReply\x12\x0e\n\x06offset\x18\x01 \x01(\t\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x30\n\x04list\x18\x03 \x03(\x0b\x32\".bilibili.app.interface.v1.BigItem\"^\n\rMediaVideoReq\x12\x0e\n\x06\x62iz_id\x18\x01 \x01(\x03\x12\x10\n\x08\x62iz_type\x18\x02 \x01(\x03\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\x03\x12\x0e\n\x06offset\x18\x05 \x01(\t\x12\n\n\x02ps\x18\x06 \x01(\x05\"\'\n\x08Overview\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"[\n\x07ShowTab\x12\x34\n\x08tab_type\x18\x01 \x01(\x0e\x32\".bilibili.app.interface.v1.TabType\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\"\xde\x01\n\tSmallItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x18\n\x10\x63over_right_text\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text1\x18\x05 \x01(\t\x12\x18\n\x10\x63over_left_icon1\x18\x06 \x01(\x03\x12\x18\n\x10\x63over_left_text2\x18\x07 \x01(\t\x12\x18\n\x10\x63over_left_icon2\x18\x08 \x01(\x03\x12\r\n\x05param\x18\t \x01(\x03\x12\x0b\n\x03mid\x18\n \x01(\x03\"$\n\x05Staff\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"O\n\x08UserCard\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x11\n\tuser_face\x18\x02 \x01(\t\x12\x10\n\x08user_url\x18\x03 \x01(\t\x12\x0b\n\x03mid\x18\x04 \x01(\x03*:\n\x07\x42utType\x12\x0f\n\x0b\x42UT_INVALID\x10\x00\x12\x10\n\x0c\x42UT_REDIRECT\x10\x01\x12\x0c\n\x08\x42UT_LIKE\x10\x02*g\n\x07TabType\x12\x0f\n\x0bTAB_INVALID\x10\x00\x12\x12\n\x0eTAB_OGV_DETAIL\x10\x06\x12\x11\n\rTAB_OGV_REPLY\x10\x07\x12\x10\n\x0cTAB_FEED_BID\x10\x08\x12\x12\n\x0eTAB_FEED_SMALL\x10\t2\x84\x04\n\x05Media\x12\\\n\x08MediaTab\x12&.bilibili.app.interface.v1.MediaTabReq\x1a(.bilibili.app.interface.v1.MediaTabReply\x12\x65\n\x0bMediaDetail\x12).bilibili.app.interface.v1.MediaDetailReq\x1a+.bilibili.app.interface.v1.MediaDetailReply\x12\x62\n\nMediaVideo\x12(.bilibili.app.interface.v1.MediaVideoReq\x1a*.bilibili.app.interface.v1.MediaVideoReply\x12k\n\rMediaRelation\x12+.bilibili.app.interface.v1.MediaRelationReq\x1a-.bilibili.app.interface.v1.MediaRelationReply\x12\x65\n\x0bMediaFollow\x12).bilibili.app.interface.v1.MediaFollowReq\x1a+.bilibili.app.interface.v1.MediaFollowReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.interfaces.v1.media_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MEDIATABREQ_ARGSENTRY._options = None
  _MEDIATABREQ_ARGSENTRY._serialized_options = b'8\001'
  _globals['_BUTTYPE']._serialized_start=3012
  _globals['_BUTTYPE']._serialized_end=3070
  _globals['_TABTYPE']._serialized_start=3072
  _globals['_TABTYPE']._serialized_end=3175
  _globals['_BIGITEM']._serialized_start=70
  _globals['_BIGITEM']._serialized_end=393
  _globals['_BUTTON']._serialized_start=396
  _globals['_BUTTON']._serialized_end=554
  _globals['_CAST']._serialized_start=556
  _globals['_CAST']._serialized_end=633
  _globals['_CHANNELINFO']._serialized_start=635
  _globals['_CHANNELINFO']._serialized_end=688
  _globals['_LIKEBUTTON']._serialized_start=691
  _globals['_LIKEBUTTON']._serialized_end=1102
  _globals['_LIKEBUTTONRESOURCE']._serialized_start=1104
  _globals['_LIKEBUTTONRESOURCE']._serialized_end=1151
  _globals['_LIKECARD']._serialized_start=1153
  _globals['_LIKECARD']._serialized_end=1196
  _globals['_MEDIACARD']._serialized_start=1199
  _globals['_MEDIACARD']._serialized_end=1328
  _globals['_MEDIADETAILREPLY']._serialized_start=1331
  _globals['_MEDIADETAILREPLY']._serialized_end=1500
  _globals['_MEDIADETAILREQ']._serialized_start=1502
  _globals['_MEDIADETAILREQ']._serialized_end=1552
  _globals['_MEDIAFOLLOWREPLY']._serialized_start=1554
  _globals['_MEDIAFOLLOWREPLY']._serialized_end=1572
  _globals['_MEDIAFOLLOWREQ']._serialized_start=1574
  _globals['_MEDIAFOLLOWREQ']._serialized_end=1616
  _globals['_MEDIAPERSON']._serialized_start=1618
  _globals['_MEDIAPERSON']._serialized_end=1722
  _globals['_MEDIARELATIONREPLY']._serialized_start=1724
  _globals['_MEDIARELATIONREPLY']._serialized_end=1830
  _globals['_MEDIARELATIONREQ']._serialized_start=1832
  _globals['_MEDIARELATIONREQ']._serialized_end=1929
  _globals['_MEDIATABREPLY']._serialized_start=1932
  _globals['_MEDIATABREPLY']._serialized_end=2143
  _globals['_MEDIATABREQ']._serialized_start=2146
  _globals['_MEDIATABREQ']._serialized_end=2333
  _globals['_MEDIATABREQ_ARGSENTRY']._serialized_start=2290
  _globals['_MEDIATABREQ_ARGSENTRY']._serialized_end=2333
  _globals['_MEDIAVIDEOREPLY']._serialized_start=2335
  _globals['_MEDIAVIDEOREPLY']._serialized_end=2436
  _globals['_MEDIAVIDEOREQ']._serialized_start=2438
  _globals['_MEDIAVIDEOREQ']._serialized_end=2532
  _globals['_OVERVIEW']._serialized_start=2534
  _globals['_OVERVIEW']._serialized_end=2573
  _globals['_SHOWTAB']._serialized_start=2575
  _globals['_SHOWTAB']._serialized_end=2666
  _globals['_SMALLITEM']._serialized_start=2669
  _globals['_SMALLITEM']._serialized_end=2891
  _globals['_STAFF']._serialized_start=2893
  _globals['_STAFF']._serialized_end=2929
  _globals['_USERCARD']._serialized_start=2931
  _globals['_USERCARD']._serialized_end=3010
  _globals['_MEDIA']._serialized_start=3178
  _globals['_MEDIA']._serialized_end=3694
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Locale(google.protobuf.message.Message):
    """区域标识
    gRPC头部:x-bili-locale-bin
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    C_LOCALE_FIELD_NUMBER: builtins.int
    S_LOCALE_FIELD_NUMBER: builtins.int
    SIM_CODE_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    @property
    def c_locale(self) -> global___LocaleIds:
        """App设置的locale"""
    @property
    def s_locale(self) -> global___LocaleIds:
        """系统默认的locale"""
    sim_code: builtins.str
    """sim卡的国家码+运营商码"""
    timezone: builtins.str
    """时区"""
    def __init__(
        self,
        *,
        c_locale: global___LocaleIds | None = ...,
        s_locale: global___LocaleIds | None = ...,
        sim_code: builtins.str = ...,
        timezone: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["c_locale", b"c_locale", "s_locale", b"s_locale"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["c_locale", b"c_locale", "s_locale", b"s_locale", "sim_code", b"sim_code", "timezone", b"timezone"]) -> None: ...

global___Locale = Locale

@typing_extensions.final
class LocaleIds(google.protobuf.message.Message):
    """Defined by https://developer.apple.com/library/archive/documentation/MacOSX/Conceptual/BPInternational/LanguageandLocaleIDs/LanguageandLocaleIDs.html"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    language: builtins.str
    """A language designator is a code that represents a language."""
    script: builtins.str
    """Writing systems."""
    region: builtins.str
    """A region designator is a code that represents a country or an area."""
    def __init__(
        self,
        *,
        language: builtins.str = ...,
        script: builtins.str = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["language", b"language", "region", b"region", "script", b"script"]) -> None: ...

global___LocaleIds = LocaleIds



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.relation.interfaces import api_pb2 as bilibili_dot_relation_dot_interfaces_dot_api__pb2


class RelationInterfaceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AtSearch = channel.unary_unary(
                '/bilibili.relation.interface.v1.RelationInterface/AtSearch',
                request_serializer=bilibili_dot_relation_dot_interfaces_dot_api__pb2.AtSearchReq.SerializeToString,
                response_deserializer=bilibili_dot_relation_dot_interfaces_dot_api__pb2.AtSearchReply.FromString,
                )


class RelationInterfaceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AtSearch(self, request, context):
        """评论区 At 用户列表 (无需登录鉴权)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RelationInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AtSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.AtSearch,
                    request_deserializer=bilibili_dot_relation_dot_interfaces_dot_api__pb2.AtSearchReq.FromString,
                    response_serializer=bilibili_dot_relation_dot_interfaces_dot_api__pb2.AtSearchReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.relation.interface.v1.RelationInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RelationInterface(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AtSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.relation.interface.v1.RelationInterface/AtSearch',
            bilibili_dot_relation_dot_interfaces_dot_api__pb2.AtSearchReq.SerializeToString,
            bilibili_dot_relation_dot_interfaces_dot_api__pb2.AtSearchReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/distribution/setting/experimental.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.distribution.v1 import distribution_pb2 as bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4bilibili/app/distribution/setting/experimental.proto\x12.bilibili.app.distribution.setting.experimental\x1a/bilibili/app/distribution/v1/distribution.proto\"F\n\rDynamicSelect\x12\x35\n\x04\x66old\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValue\"u\n\x03\x45xp\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12\x38\n\x06\x62ucket\x18\x02 \x01(\x0b\x32(.bilibili.app.distribution.v1.Int32Value\"\x90\x01\n\x12\x45xperimentalConfig\x12\x37\n\x04\x66lag\x18\x01 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12\x41\n\x04\x65xps\x18\x02 \x03(\x0b\x32\x33.bilibili.app.distribution.setting.experimental.Exp\"\xb5\x01\n\x11MultipleTusConfig\x12I\n\x08top_left\x18\x01 \x01(\x0b\x32\x37.bilibili.app.distribution.setting.experimental.TopLeft\x12U\n\x0e\x64ynamic_select\x18\x02 \x01(\x0b\x32=.bilibili.app.distribution.setting.experimental.DynamicSelect\"\x96\x07\n\x07TopLeft\x12\x36\n\x03url\x18\x01 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12I\n\x16story_foreground_image\x18\x02 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12I\n\x16story_background_image\x18\x03 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12J\n\x17listen_foreground_image\x18\x04 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12J\n\x17listen_background_image\x18\x05 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12M\n\x1aios_story_foreground_image\x18\x06 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12M\n\x1aios_story_background_image\x18\x07 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12N\n\x1bios_listen_foreground_image\x18\x08 \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12N\n\x1bios_listen_background_image\x18\t \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12\x37\n\x04goto\x18\n \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12\x39\n\x06url_v2\x18\x0b \x01(\x0b\x32).bilibili.app.distribution.v1.StringValue\x12\x39\n\x07goto_v2\x18\x0c \x01(\x0b\x32(.bilibili.app.distribution.v1.Int64Value\x12\x38\n\x05\x62\x61\x64ge\x18\r \x01(\x0b\x32).bilibili.app.distribution.v1.StringValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.distribution.setting.experimental_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DYNAMICSELECT']._serialized_start=153
  _globals['_DYNAMICSELECT']._serialized_end=223
  _globals['_EXP']._serialized_start=225
  _globals['_EXP']._serialized_end=342
  _globals['_EXPERIMENTALCONFIG']._serialized_start=345
  _globals['_EXPERIMENTALCONFIG']._serialized_end=489
  _globals['_MULTIPLETUSCONFIG']._serialized_start=492
  _globals['_MULTIPLETUSCONFIG']._serialized_end=673
  _globals['_TOPLEFT']._serialized_start=676
  _globals['_TOPLEFT']._serialized_end=1594
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/distribution/setting/download.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.distribution.v1 import distribution_pb2 as bilibili_dot_app_dot_distribution_dot_v1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0bilibili/app/distribution/setting/download.proto\x12*bilibili.app.distribution.setting.download\x1a/bilibili/app/distribution/v1/distribution.proto\"e\n\x16\x44ownloadSettingsConfig\x12K\n\x1a\x65nable_download_auto_start\x18\x01 \x01(\x0b\x32\'.bilibili.app.distribution.v1.BoolValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.distribution.setting.download_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DOWNLOADSETTINGSCONFIG']._serialized_start=145
  _globals['_DOWNLOADSETTINGSCONFIG']._serialized_end=246
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.broadcast.message.main.native_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetActProgressReq(google.protobuf.message.Message):
    """获取Native页进度数据-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGEID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    pageID: builtins.int
    """Native页id"""
    mid: builtins.int
    """用户mid"""
    def __init__(
        self,
        *,
        pageID: builtins.int = ...,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "pageID", b"pageID"]) -> None: ...

global___GetActProgressReq = GetActProgressReq

@typing_extensions.final
class GetActProgressReply(google.protobuf.message.Message):
    """获取Native页进度数据-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_FIELD_NUMBER: builtins.int
    @property
    def event(self) -> bilireq.grpc.protos.bilibili.broadcast.message.main.native_pb2.NativePageEvent:
        """进度数据"""
    def __init__(
        self,
        *,
        event: bilireq.grpc.protos.bilibili.broadcast.message.main.native_pb2.NativePageEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event", b"event"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event", b"event"]) -> None: ...

global___GetActProgressReply = GetActProgressReply



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/interfaces/v1/space.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from bilireq.grpc.protos.bilibili.app.archive.v1 import archive_pb2 as bilibili_dot_app_dot_archive_dot_v1_dot_archive__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&bilibili/app/interfaces/v1/space.proto\x12\x19\x62ilibili.app.interface.v1\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a%bilibili/app/archive/v1/archive.proto\x1a%bilibili/app/dynamic/v2/dynamic.proto\"A\n\x03\x41rc\x12-\n\x07\x61rchive\x18\x01 \x01(\x0b\x32\x1c.bilibili.app.archive.v1.Arc\x12\x0b\n\x03uri\x18\x02 \x01(\t\"@\n\x07\x44ynamic\x12\x35\n\x07\x64ynamic\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"M\n\x0eSearchTabReply\x12\r\n\x05\x66ocus\x18\x01 \x01(\x03\x12,\n\x04tabs\x18\x02 \x03(\x0b\x32\x1e.bilibili.app.interface.v1.Tab\":\n\x0cSearchTabReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x03 \x01(\x05\"U\n\x12SearchArchiveReply\x12\x30\n\x08\x61rchives\x18\x01 \x03(\x0b\x32\x1e.bilibili.app.interface.v1.Arc\x12\r\n\x05total\x18\x02 \x01(\x03\"\x8d\x01\n\x10SearchArchiveReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\n\n\x02pn\x18\x03 \x01(\x03\x12\n\n\x02ps\x18\x04 \x01(\x03\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"Y\n\x12SearchDynamicReply\x12\x34\n\x08\x64ynamics\x18\x01 \x03(\x0b\x32\".bilibili.app.interface.v1.Dynamic\x12\r\n\x05total\x18\x02 \x01(\x03\"\x8d\x01\n\x10SearchDynamicReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\n\n\x02pn\x18\x03 \x01(\x03\x12\n\n\x02ps\x18\x04 \x01(\x03\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"!\n\x03Tab\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t*&\n\x04\x46rom\x12\x0e\n\nArchiveTab\x10\x00\x12\x0e\n\nDynamicTab\x10\x01\x32\xc2\x02\n\x05Space\x12_\n\tSearchTab\x12\'.bilibili.app.interface.v1.SearchTabReq\x1a).bilibili.app.interface.v1.SearchTabReply\x12k\n\rSearchArchive\x12+.bilibili.app.interface.v1.SearchArchiveReq\x1a-.bilibili.app.interface.v1.SearchArchiveReply\x12k\n\rSearchDynamic\x12+.bilibili.app.interface.v1.SearchDynamicReq\x1a-.bilibili.app.interface.v1.SearchDynamicReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.interfaces.v1.space_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FROM']._serialized_start=970
  _globals['_FROM']._serialized_end=1008
  _globals['_ARC']._serialized_start=197
  _globals['_ARC']._serialized_end=262
  _globals['_DYNAMIC']._serialized_start=264
  _globals['_DYNAMIC']._serialized_end=328
  _globals['_SEARCHTABREPLY']._serialized_start=330
  _globals['_SEARCHTABREPLY']._serialized_end=407
  _globals['_SEARCHTABREQ']._serialized_start=409
  _globals['_SEARCHTABREQ']._serialized_end=467
  _globals['_SEARCHARCHIVEREPLY']._serialized_start=469
  _globals['_SEARCHARCHIVEREPLY']._serialized_end=554
  _globals['_SEARCHARCHIVEREQ']._serialized_start=557
  _globals['_SEARCHARCHIVEREQ']._serialized_end=698
  _globals['_SEARCHDYNAMICREPLY']._serialized_start=700
  _globals['_SEARCHDYNAMICREPLY']._serialized_end=789
  _globals['_SEARCHDYNAMICREQ']._serialized_start=792
  _globals['_SEARCHDYNAMICREQ']._serialized_end=933
  _globals['_TAB']._serialized_start=935
  _globals['_TAB']._serialized_end=968
  _globals['_SPACE']._serialized_start=1011
  _globals['_SPACE']._serialized_end=1333
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/api/ticket/v1/ticket.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#bilibili/api/ticket/v1/ticket.proto\x12\x16\x62ilibili.api.ticket.v1\"\xb7\x01\n\x10GetTicketRequest\x12\x46\n\x07\x63ontext\x18\x01 \x03(\x0b\x32\x35.bilibili.api.ticket.v1.GetTicketRequest.ContextEntry\x12\x0e\n\x06key_id\x18\x02 \x01(\t\x12\x0c\n\x04sign\x18\x03 \x01(\x0c\x12\r\n\x05token\x18\x04 \x01(\t\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xa6\x01\n\x11GetTicketResponse\x12\x0e\n\x06ticket\x18\x01 \x01(\t\x12\x12\n\ncreated_at\x18\x02 \x01(\x03\x12\x0b\n\x03ttl\x18\x03 \x01(\x03\x12\x42\n\x07\x63ontext\x18\x04 \x01(\x0b\x32\x31.bilibili.api.ticket.v1.GetTicketResponse.Context\x1a\x1c\n\x07\x43ontext\x12\x11\n\tv_voucher\x18\x01 \x01(\t2j\n\x06Ticket\x12`\n\tGetTicket\x12(.bilibili.api.ticket.v1.GetTicketRequest\x1a).bilibili.api.ticket.v1.GetTicketResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.api.ticket.v1.ticket_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETTICKETREQUEST_CONTEXTENTRY._options = None
  _GETTICKETREQUEST_CONTEXTENTRY._serialized_options = b'8\001'
  _globals['_GETTICKETREQUEST']._serialized_start=64
  _globals['_GETTICKETREQUEST']._serialized_end=247
  _globals['_GETTICKETREQUEST_CONTEXTENTRY']._serialized_start=201
  _globals['_GETTICKETREQUEST_CONTEXTENTRY']._serialized_end=247
  _globals['_GETTICKETRESPONSE']._serialized_start=250
  _globals['_GETTICKETRESPONSE']._serialized_end=416
  _globals['_GETTICKETRESPONSE_CONTEXT']._serialized_start=388
  _globals['_GETTICKETRESPONSE_CONTEXT']._serialized_end=416
  _globals['_TICKET']._serialized_start=418
  _globals['_TICKET']._serialized_end=524
# @@protoc_insertion_point(module_scope)
